
import java.awt.*;
import javax.swing.*;
import sprite.*;

/**
 * A panel that shows 100 small smiley-type faces bouncing around. All the
 * faces start at the point (400,300) and fan out from there with a
 * random speed between 3 and 8.  Pressing the space bar will pause/restart
 * the animation.  Pressing the Q key will end the program.
 */
public class SpriteDemo1 extends SpritePanel {
	
	/**
	 * Creates a panel showing the 100 faces.  The preferred size
	 * of the panel is 800-by-600, the default inherited from SpritePanel.
	 */
	public SpriteDemo1() {
		for (int i = 0; i < 100; i++) {
			ImageSprite img;
			switch ( (int)(3*Math.random()) ) {
			case 0:
				img = new ImageSprite("images/face-smile.png");
				break;
			case 1:
				img = new ImageSprite("images/face-sad.png");
				break;
			default:
				img = new ImageSprite("images/face-wink.png");
				break;
			}
			img.setLocation(400,300);
			img.randomVelocity(3, 8);
			addSprite(img);
		}
		installKeyPress("SPACE");
		installKeyPress("Q");
	}
	
	/**
	 * Respond to the SPACE and Q keys.  (The constructor sets up
	 * the event-handler to send those key presses to this method.)
	 */
	protected void doKeyPress( String keyStrokeString ) {
		if (keyStrokeString.equals("Q")) {
			System.exit(0);
		}
		else if (keyStrokeString.equals("SPACE")) {
			if (isPaused())
				go();
			else
				pause();
		}
	}
	
	/**
	 * This main routine makes it possible to run the class SpriteDemo1
	 * as an application.  (It has nothing to do with objects of type SpriteDemo1,
	 * and should perhaps be in another class.)  This routine opens a window
	 * that contains a panel of type SpriteDemo1.
	 */
	public static void main(String[] args) {
		JFrame window = new JFrame("Sprite Demo 1");
		SpritePanel panel = new SpriteDemo1();
		window.setContentPane(panel);
		window.pack();
		window.setResizable(false);
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		window.setLocation( (screen.width - window.getWidth())/2, 
				(screen.height - window.getHeight())/2 );
		window.setVisible(true);
		panel.go(); // Required to start the animation!!
	}

}
